// PyBEST: Pythonic Black-box Electronic Structure Tool
// Copyright (C) 2016-- The PyBEST Development Team
//
// This file is part of PyBEST.
//
// PyBEST is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 3
// of the License, or (at your option) any later version.
//
// PyBEST is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <http://www.gnu.org/licenses/>
// --
#ifndef PyBEST_GBASIS_LIBINT_UTILS_H
#define PyBEST_GBASIS_LIBINT_UTILS_H

#include <nanobind/nanobind.h>
#include <nanobind/ndarray.h>

#include <vector>

#include "basis.h"
namespace nb = nanobind;

// Libint Gaussian integrals library
#include <libint2.hpp>
#if !LIBINT2_CONSTEXPR_STATICS
#include <libint2/statics_definition.h>
#endif

#if LIBINT2_REALTYPE != double
#error LibInt must be compiled with REALTYPE=double.
#endif

#if LIBINT2_SUPPORT_ERI == 0
#error LibInt must be compiled with support for electron repulsion integrals.
#endif

#ifndef LIBINT2_MAX_AM
#define LIBINT2_MAX_AM LIBINT2_MAX_AM_ERI
#endif
#if LIBINT2_MAX_AM < MAX_SHELL_TYPE
#error LibInt must be compiled with an angular momentum limit of at least MAX_SHELL_TYPE.
#endif

namespace py_libint_utils {
size_t get_tot_nbasis(const std::vector<libint2::Shell>& shells);
libint2::BasisSet uncontract_basis_set(Basis* basis);
size_t get_nubf(Basis* basis, bool solid);
void get_solid_tform_u2c(Basis* basis, nb::ndarray<nb::numpy, double>& out,
                         size_t ncbf, size_t nubf);
}  // namespace py_libint_utils
#endif
