#!/usr/bin/env python3

# This script uses the data generated by the dumping.py script
# Thus, first run dumping.py, before executing this example script

from pybest.io import IOData

# Read internal checkpoint file
# -----------------------------
data = IOData.from_file("checkpoint.h5")

# Print all attributes that are contained in checkpoint file
# ----------------------------------------------------------
print("\ninternal file:")
print(data.__dict__)

# Modify data as you please
# -------------------------
del data.eri
print(data.__dict__)

# Read xyz file (atoms and coordinates only)
# ------------------------------------------
data = IOData.from_file("mol.xyz")

# Print all attributes that are read in from xyz file
# ---------------------------------------------------
print("\nxyz file:")
print(data.__dict__)

# Read molden file
# ----------------
data = IOData.from_file("water-scf.molden")

# Print all attributes that are read in from xyz file
# ---------------------------------------------------
print("\nmolden file:")
print(data.__dict__)

# Access attributes separately
coord = data.coordinates  # np.array
factory = data.gobasis  # Basis instance
atom = data.atom  # list of str
orb_a = data.orb_a  # orbitals

# Read FCIDUMP file
# -----------------
data = IOData.from_file("hamiltonian_mo.FCIDUMP")

# Print all attributes that are read in from FCIDUMP file
# -------------------------------------------------------
print("\nFCIDUMP file:")
print(data.__dict__)

# Access attributes separately
one = data.one  # one-electron integrals
two = data.two  # two-electron integrals
e_core = data.e_core  # core energy
orb_a = data.orb_a  # orbitals (assuming orthonormal orbitals)
olp = data.olp  # overlap matrix (assuming orthonormal orbitals)
lf = data.lf  # an instance of DenseLinalgFactory
